 
/* 
 *      (c) Copyright 1991 Sun Microsystems, Inc. Sun design patents 
 *      pending in the U.S. and foreign countries. See LEGAL NOTICE 
 *      file for terms of the license.
 */

#include <X11/Intrinsic.h>
#include "XtToken.h"
/*
 * Do NOT include XtmtDefs.h here.
 */


/*
 * Intrinsic.h does not export its CONST declaration.
 * This is not really important because these functions
 * will not be compiled by C++, but they remain in the
 * argument list declarations nonetheless.
 */
#define CONST


/*
 * should be protected but are not in Intrinsic.h:
 *	XtManageChild();
 *	XtManageChildren();
 */

void
XrmCompileResourceListR(resources, num_resources)
	XtResourceList  resources;
	Cardinal        num_resources;
{
	XtGetToken();
	XrmCompileResourceList(resources, num_resources);
	XtReleaseToken();
}


void
XtAddActionsR(actions, num_actions)
	XtActionList    actions;
	Cardinal        num_actions;
{
	XtGetToken();
	XtAddActions(actions, num_actions);
	XtReleaseToken();
}


void
XtAddCallbackR(widget, callback_name, callback, closure)
	Widget          widget;
	CONST String    callback_name;
	XtCallbackProc  callback;
	XtPointer       closure;
{
	XtGetToken();
	XtAddCallback(widget, callback_name, callback, closure);
	XtReleaseToken();
}


void
XtAddCallbacksR(widget, callback_name, callbacks)
	Widget          widget;
	CONST String    callback_name;
	XtCallbackList  callbacks;
{
	XtGetToken();
	XtAddCallbacks(widget, callback_name, callbacks);
	XtReleaseToken();
}


void
XtAddEventHandlerR(widget, eventMask, nonmaskable, proc, closure)
	Widget          widget;
	EventMask       eventMask;
	Boolean         nonmaskable;
	XtEventHandler  proc;
	XtPointer       closure;
{
	XtGetToken();
	XtAddEventHandler(widget, eventMask, nonmaskable, proc, closure);
	XtReleaseToken();
}


void
XtAddExposureToRegionR(event, region)
	XEvent         *event;
	Region          region;
{
	XtGetToken();
	XtAddExposureToRegion(event, region);
	XtReleaseToken();
}


void
XtAddGrabR(widget, exclusive, spring_loaded)
	Widget          widget;
	Boolean         exclusive;
	Boolean         spring_loaded;
{
	XtGetToken();
	XtAddGrab(widget, exclusive, spring_loaded);
	XtReleaseToken();
}


XtInputId
XtAddInputR(source, condition, proc, closure)
	int             source;
	XtPointer       condition;
	XtInputCallbackProc proc;
	XtPointer       closure;
{
	XtInputId return_val;

	XtGetToken();
	return_val = XtAddInput(source, condition, proc, closure);
	XtReleaseToken();
	return return_val;
}


void
XtAddRawEventHandlerR(widget, eventMask, nonmaskable, proc, closure)
	Widget          widget;
	EventMask       eventMask;
	Boolean         nonmaskable;
	XtEventHandler  proc;
	XtPointer       closure;
{
	XtGetToken();
	XtAddRawEventHandler(widget, eventMask, nonmaskable, proc, closure);
	XtReleaseToken();
}


XtIntervalId
XtAddTimeOutR(interval, proc, closure)
	unsigned long   interval;
	XtTimerCallbackProc proc;
	XtPointer       closure;
{
	XtIntervalId	return_val;

	XtGetToken();
	return_val = XtAddTimeOut(interval, proc, closure);
	XtReleaseToken();
	return return_val;
}


XtWorkProcId
XtAddWorkProcR(proc, closure)
	XtWorkProc      proc;
	XtPointer       closure;
{
	XtWorkProcId return_val;

	XtGetToken();
	return_val = XtAddWorkProc(proc, closure);
	XtReleaseToken();
	return return_val;
}


XtActionHookId
XtAppAddActionHookR(app, proc, client_data)
	XtAppContext    app;
	XtActionHookProc proc;
	XtPointer       client_data;
{
	XtActionHookId	return_val;

	XtGetToken();	
	return_val = XtAppAddActionHook(app, proc, client_data);
	XtReleaseToken();
	return return_val;
}


void
XtAppAddActionsR(app, actions, num_actions)
	XtAppContext    app;
	XtActionList    actions;
	Cardinal        num_actions;
{
	XtGetToken();
	XtAppAddActions(app, actions, num_actions);
	XtReleaseToken();
}


XtInputId
XtAppAddInputR(app, source, condition, proc, closure)
	XtAppContext    app;
	int             source;
	XtPointer       condition;
	XtInputCallbackProc proc;
	XtPointer       closure;
{
	XtInputId return_val;

	XtGetToken();
	return_val = XtAppAddInput(app, source, condition, proc, closure);
	XtReleaseToken();
	return return_val;
}


XtIntervalId
XtAppAddTimeOutR(app, interval, proc, closure)
	XtAppContext    app;
	unsigned long   interval;
	XtTimerCallbackProc proc;
	XtPointer       closure;
{
	XtIntervalId return_val;

	XtGetToken();
	return_val = XtAppAddTimeOut(app, interval, proc, closure);
	XtReleaseToken();
	return return_val;
}


XtWorkProcId
XtAppAddWorkProcR(app, proc, closure)
	XtAppContext    app;
	XtWorkProc      proc;
	XtPointer       closure;
{
	XtWorkProcId return_val;

	XtGetToken();
	return_val = XtAppAddWorkProc(app, proc, closure);
	XtReleaseToken();
	return return_val;
}


Widget
XtAppCreateShellR(name, class, widget_class, display, args, num_args)
	CONST String    name;
	CONST String    class;
	WidgetClass     widget_class;
	Display        *display;
	ArgList         args;
	Cardinal        num_args;
{
	Widget return_val;

	XtGetToken();
	return_val = XtAppCreateShell(name, class, widget_class, display, args, num_args);
	XtReleaseToken();
	return return_val;
}


void
XtAppErrorR(app, message)
	XtAppContext    app;
	CONST String    message;
{
	XtGetToken();
	XtAppError(app, message);
	XtReleaseToken();
}


void
XtAppErrorMsgR(app, name, type, class, defaultp, params, num_params)
	XtAppContext    app;
	CONST String    name;
	CONST String    type;
	CONST String    class;
	CONST String    defaultp;
	String         *params;
	Cardinal       *num_params;
{
	XtGetToken();
	XtAppErrorMsg(app, name, type, class, defaultp, params, num_params);
	XtReleaseToken();
}


XrmDatabase    *
XtAppGetErrorDatabaseR(app)
	XtAppContext    app;
{
	XrmDatabase *return_val;

	XtGetToken();
	return_val = XtAppGetErrorDatabase(app);
	XtReleaseToken();
	return return_val;
}


void
XtAppGetErrorDatabaseTextR(app, name, type, class, defaultp, buffer, nbytes, database)
	XtAppContext    app;
	CONST String    name;
	CONST String    type;
	CONST String    class;
	CONST String    defaultp;
	String          buffer;
	int             nbytes;
	XrmDatabase     database;
{
	XtGetToken();
	XtAppGetErrorDatabaseText(app, name, type, class, defaultp, buffer, nbytes, database);
	XtReleaseToken();
}


unsigned int
XtAppGetSelectionTimeoutR(app)
	XtAppContext    app;
{
	unsigned int return_val;

	XtGetToken();
	return_val = XtAppGetSelectionTimeout(app);
	XtReleaseToken();
	return return_val;
}


Widget
XtAppInitializeR(app_context_return, application_class, options, num_options, argc_in_out, argv_in_out, fallback_resources, args, num_args)
	XtAppContext   *app_context_return;
	CONST String    application_class;
	XrmOptionDescList options;
	Cardinal        num_options;
	Cardinal       *argc_in_out;
	String         *argv_in_out;
	CONST String   *fallback_resources;
	ArgList         args;
	Cardinal        num_args;
{
	Widget return_val;

	XtInitializeToken();
	return_val = XtAppInitialize(app_context_return, application_class, options, num_options, argc_in_out, argv_in_out, fallback_resources, args, num_args);
	XtInitializeTokenDispatch();
	return return_val;
}


void
XtAppMainLoopR(app)
	XtAppContext    app;
{
	XtGetToken();
	XtAppMainLoop(app);
	XtReleaseToken();
}


void
XtAppNextEventR(appContext, event)
	XtAppContext    appContext;
	XEvent         *event;
{
	XtGetToken();
	XtAppNextEvent(appContext, event);
	XtReleaseToken();
}


Boolean
XtAppPeekEventR(appContext, event)
	XtAppContext    appContext;
	XEvent         *event;
{
	Boolean return_val;

	XtGetToken();
	return_val = XtAppPeekEvent(appContext, event);
	XtReleaseToken();
	return return_val;
}


XtInputMask
XtAppPendingR(appContext)
	XtAppContext    appContext;
{
	XtInputMask return_val;

	XtGetToken();
	return_val = XtAppPending(appContext);
	XtReleaseToken();
	return return_val;
}


void
XtAppProcessEventR(app, mask)
	XtAppContext    app;
	XtInputMask     mask;
{
	XtGetToken();
	XtAppProcessEvent(app, mask);
	XtReleaseToken();
}


XtErrorHandler
XtAppSetErrorHandlerR(app, handler)
	XtAppContext    app;
	XtErrorHandler  handler;
{
	XtErrorHandler return_val;
	
	XtGetToken();
	return_val = XtAppSetErrorHandler(app, handler);
	XtReleaseToken();
	return return_val;
}


XtErrorMsgHandler
XtAppSetErrorMsgHandlerR(app, handler)
	XtAppContext    app;
	XtErrorMsgHandler handler;
{
	XtErrorMsgHandler return_val;
	
	XtGetToken();
	return_val = XtAppSetErrorMsgHandler(app, handler);
	XtReleaseToken();
	return return_val;
}


void
XtAppSetFallbackResourcesR(app_context, specification_list)
	XtAppContext    app_context;
	CONST String   *specification_list;
{
	XtGetToken();
	XtAppSetFallbackResources(app_context, specification_list);
	XtReleaseToken();
}


void
XtAppSetSelectionTimeoutR(app, timeout)
	XtAppContext    app;
	unsigned long   timeout;
{
	XtGetToken();
	XtAppSetSelectionTimeout(app, timeout);
	XtReleaseToken();
}


void
XtAppSetTypeConverterR(app_context, from_type, to_type, converter, convert_args, num_args, cache_type, destructor)
	XtAppContext    app_context;
	CONST String    from_type;
	CONST String    to_type;
	XtTypeConverter converter;
	XtConvertArgList convert_args;
	Cardinal        num_args;
	XtCacheType     cache_type;
	XtDestructor    destructor;
{
	XtGetToken();
	XtAppSetTypeConverter(app_context, from_type, to_type, converter, convert_args, num_args, cache_type, destructor);
	XtReleaseToken();
}


XtErrorHandler
XtAppSetWarningHandlerR(app, handler)
	XtAppContext    app;
	XtErrorHandler  handler;
{
	XtErrorHandler return_val;

	XtGetToken();
	return_val = XtAppSetWarningHandler(app, handler);
	XtReleaseToken();
	return return_val;
}


XtErrorMsgHandler
XtAppSetWarningMsgHandlerR(app, handler)
	XtAppContext    app;
	XtErrorMsgHandler handler;
{
	XtErrorMsgHandler return_val;

	XtGetToken();
	return_val = XtAppSetWarningMsgHandler(app, handler);
	XtReleaseToken();
	return return_val;
}


void
XtAppWarningR(app, message)
	XtAppContext    app;
	CONST String    message;
{
	XtGetToken();
	XtAppWarning(app, message);
	XtReleaseToken();
}


void
XtAppWarningMsgR(app, name, type, class, defaultp, params, num_params)
	XtAppContext    app;
	CONST String    name;
	CONST String    type;
	CONST String    class;
	CONST String    defaultp;
	String         *params;
	Cardinal       *num_params;
{
	XtGetToken();
	XtAppWarningMsg(app, name, type, class, defaultp, params, num_params);
	XtReleaseToken();
}


void
XtAugmentTranslationsR(widget, new)
	Widget          widget;
	XtTranslations  new;
{
	XtGetToken();
	XtAugmentTranslations(widget, new);
	XtReleaseToken();
}


EventMask
XtBuildEventMaskR(widget)
	Widget          widget;
{
	EventMask return_val;

	XtGetToken();
	return_val = XtBuildEventMask(widget);
	XtReleaseToken();
	return return_val;
}


Boolean
XtCallAcceptFocusR(widget, t)
	Widget          widget;
	Time           *t;
{
	Boolean return_val;

	XtGetToken();
	return_val = XtCallAcceptFocus(widget, t);
	XtReleaseToken();
	return return_val;
}


void
XtCallActionProcR(widget, action, event, params, num_params)
	Widget          widget;
	CONST String    action;
	XEvent         *event;
	String         *params;
	Cardinal        num_params;
{
	XtGetToken();
	XtCallActionProc(widget, action, event, params, num_params);
	XtReleaseToken();
}


void
XtCallCallbackListR(widget, callbacks, call_data)
	Widget          widget;
	XtCallbackList  callbacks;
	XtPointer       call_data;
{
	XtGetToken();
	XtCallCallbackList(widget, callbacks, call_data);
	XtReleaseToken();
}


void
XtCallCallbacksR(widget, callback_name, call_data)
	Widget          widget;
	CONST String    callback_name;
	XtPointer       call_data;
{
	XtGetToken();
	XtCallCallbacks(widget, callback_name, call_data);
	XtReleaseToken();
}


Boolean
XtCallConverterR(dpy, converter, args, num_args, from, to_return, cache_ref_return)
	Display        *dpy;
	XtTypeConverter converter;
	XrmValuePtr     args;
	Cardinal        num_args;
	XrmValuePtr     from;
	XrmValue       *to_return;
	XtCacheRef     *cache_ref_return;
{
	Boolean return_val;

	XtGetToken();
	return_val = XtCallConverter(dpy, converter, args, num_args, from, to_return, cache_ref_return);
	XtReleaseToken();
	return return_val;
}


void
XtCallbackExclusiveR(widget, closure, call_data)
	Widget          widget;
	XtPointer       closure;
	XtPointer       call_data;
{
	XtGetToken();
	XtCallbackExclusive(widget, closure, call_data);
	XtReleaseToken();
}


void
XtCallbackNoneR(widget, closure, call_data)
	Widget          widget;
	XtPointer       closure;
	XtPointer       call_data;
{
	XtGetToken();
	XtCallbackNone(widget, closure, call_data);
	XtReleaseToken();
}


void
XtCallbackNonexclusiveR(widget, closure, call_data)
	Widget          widget;
	XtPointer       closure;
	XtPointer       call_data;
{
	XtGetToken();
	XtCallbackNonexclusive(widget, closure, call_data);
	XtReleaseToken();
}


void
XtCallbackPopdownR(widget, closure, call_data)
	Widget          widget;
	XtPointer       closure;
	XtPointer       call_data;
{
	XtGetToken();
	XtCallbackPopdown(widget, closure, call_data);
	XtReleaseToken();
}


void
XtCallbackReleaseCacheRefR(widget, closure, call_data)
	Widget          widget;
	XtPointer       closure;
	XtPointer       call_data;
{
	XtGetToken();
	XtCallbackReleaseCacheRef(widget, closure, call_data);
	XtReleaseToken();
}

void
XtCallbackReleaseCacheRefListR(widget, closure, call_data)
	Widget          widget;
	XtPointer       closure;
	                XtPointer call_data;
{
	XtGetToken();
	XtCallbackReleaseCacheRefList(widget, closure, call_data);
	XtReleaseToken();
}


char           *
XtCallocR(num, size)
	Cardinal        num;
	Cardinal        size;
{
	char *return_val;

	XtGetToken();
	return_val = XtCalloc(num, size);
	XtReleaseToken();
	return return_val;
}


WidgetClass
XtClassR(object)
	Widget          object;
{
	WidgetClass return_val;

	XtGetToken();
	return_val = XtClass(object);
	XtReleaseToken();
	return return_val;
}


void
XtCloseDisplayR(dpy)
	Display        *dpy;
{
	XtGetToken();
	XtCloseDisplay(dpy);
	XtReleaseToken();
}


void
XtConvertR(widget, from_type, from, to_type, to_return)
	Widget          widget;
	CONST String    from_type;
	XrmValue       *from;
	CONST String    to_type;
	XrmValue       *to_return;
{
	XtGetToken();
	XtConvert(widget, from_type, from, to_type, to_return);
	XtReleaseToken();
}


Boolean
XtConvertAndStoreR(widget, from_type, from, to_type, to_in_out)
	Widget          widget;
	CONST String    from_type;
	XrmValue       *from;
	CONST String    to_type;
	XrmValue       *to_in_out;
{
	Boolean return_val;

	XtGetToken();
	return_val = XtConvertAndStore(widget, from_type, from, to_type, to_in_out);
	XtReleaseToken();
	return return_val;
}


void
XtConvertCaseR(dpy, keysym, lower_return, upper_return)
	Display        *dpy;
	KeySym          keysym;
	KeySym         *lower_return;
	KeySym         *upper_return;
{
	XtGetToken();
	XtConvertCase(dpy, keysym, lower_return, upper_return);
	XtReleaseToken();
}


void
XtCopyAncestorSensitiveR(widget, offset, value)
	Widget          widget;
	int             offset;
	XrmValue       *value;
{
	XtGetToken();
	XtCopyAncestorSensitive(widget, offset, value);
	XtReleaseToken();
}


void
XtCopyDefaultColormapR(widget, offset, value)
	Widget          widget;
	int             offset;
	XrmValue       *value;
{
	XtGetToken();
	XtCopyDefaultColormap(widget, offset, value);
	XtReleaseToken();
}


void
XtCopyDefaultDepthR(widget, offset, value)
	Widget          widget;
	int             offset;
	XrmValue       *value;
{
	XtGetToken();
	XtCopyDefaultDepth(widget, offset, value);
	XtReleaseToken();
}


void
XtCopyFromParentR(widget, offset, value)
	Widget          widget;
	int             offset;
	XrmValue       *value;
{
	XtGetToken();
	XtCopyFromParent(widget, offset, value);
	XtReleaseToken();
}


void
XtCopyScreenR(widget, offset, value)
	Widget          widget;
	int             offset;
	XrmValue       *value;
{
	XtGetToken();
	XtCopyScreen(widget, offset, value);
	XtReleaseToken();
}


XtAppContext
XtCreateApplicationContextR()
{
	XtAppContext return_val;

	XtGetToken();
	return_val = XtCreateApplicationContext();
	XtReleaseToken();
	return return_val;
}


Widget
XtCreateApplicationShellR(name, widget_class, args, num_args)
	CONST String    name;
	WidgetClass     widget_class;
	ArgList         args;
	Cardinal        num_args;
{
	Widget return_val;

	XtGetToken();
	return_val = XtCreateApplicationShell(name, widget_class, args, num_args);
	XtReleaseToken();
	return return_val;
}


Widget
XtCreateManagedWidgetR(name, widget_class, parent, args, num_args)
	CONST String    name;
	WidgetClass     widget_class;
	Widget          parent;
	ArgList         args;
	Cardinal        num_args;
{
	Widget return_val;

	XtGetToken();
	return_val = XtCreateManagedWidget(name, widget_class, parent, args, num_args);
	XtReleaseToken();
	return return_val;
}


Widget
XtCreatePopupShellR(name, widgetClass, parent, args, num_args)
	CONST String    name;
	WidgetClass     widgetClass;
	Widget          parent;
	ArgList         args;
	Cardinal        num_args;
{
	Widget return_val;

	XtGetToken();
	return_val = XtCreatePopupShell(name, widgetClass, parent, args, num_args);
	XtReleaseToken();
	return return_val;
}


Widget
XtCreateWidgetR(name, widget_class, parent, args, num_args)
	CONST String    name;
	WidgetClass     widget_class;
	Widget          parent;
	ArgList         args;
	Cardinal        num_args;
{
	Widget return_val;

	XtGetToken();
	return_val = XtCreateWidget(name, widget_class, parent, args, num_args);
	XtReleaseToken();
	return return_val;
}


XrmDatabase
XtDatabaseR(dpy)
	Display        *dpy;
{
	XrmDatabase return_val;

	XtGetToken();
	return_val = XtDatabase(dpy);
	XtReleaseToken();
	return return_val;
}


void
XtDestroyApplicationContextR(appContext)
	XtAppContext    appContext;
{
	XtGetToken();
	XtDestroyApplicationContext(appContext);
	XtReleaseToken();
}


void
XtDestroyGCR(gc)
	GC              gc;
{
	XtGetToken();
	XtDestroyGC(gc);
	XtReleaseToken();
}


void
XtDestroyWidgetR(widget)
	Widget          widget;
{
	XtGetToken();
	XtDestroyWidget(widget);
	XtReleaseToken();
}


void
XtDirectConvertR(converter, args, num_args, from, to_return)
	XtConverter     converter;
	XrmValuePtr     args;
	Cardinal        num_args;
	XrmValuePtr     from;
	XrmValue       *to_return;
{
	XtGetToken();
	XtDirectConvert(converter, args, num_args, from, to_return);
	XtReleaseToken();
}


void
XtDisownSelectionR(widget, selection, time)
	Widget          widget;
	Atom            selection;
	Time            time;
{
	XtGetToken();
	XtDisownSelection(widget, selection, time);
	XtReleaseToken();
}


Boolean
XtDispatchEventR(event)
	XEvent         *event;
{
	Boolean return_val;

	XtGetToken();
	return_val = XtDispatchEvent(event);
	XtReleaseToken();
	return return_val;
}


Display        *
XtDisplayR(widget)
	Widget          widget;
{
	Display *return_val;

	XtGetToken();
	return_val = XtDisplay(widget);
	XtReleaseToken();
	return return_val;
}


void
XtDisplayInitializeR(appContext, dpy, name, class, options, num_options, argc, argv)
	XtAppContext    appContext;
	Display        *dpy;
	CONST String    name;
	CONST String    class;
	XrmOptionDescRec *options;
	Cardinal        num_options;
	Cardinal       *argc;
	char          **argv;
{
	XtGetToken();
	XtDisplayInitialize(appContext, dpy, name, class, options, num_options, argc, argv);
	XtReleaseToken();
}


Display        *
XtDisplayOfObjectR(object)
	Widget          object;
{
	Display *return_val;

	XtGetToken();
	return_val = XtDisplayOfObject(object);
	XtReleaseToken();
	return return_val;
}


void
XtDisplayStringConversionWarningR(dpy, from, toType)
	Display        *dpy;
	CONST String    from;
	CONST String    toType;
{
	XtGetToken();
	XtDisplayStringConversionWarning(dpy, from, toType);
	XtReleaseToken();
}


XtAppContext
XtDisplayToApplicationContextR(dpy)
	Display        *dpy;
{
	XtAppContext return_val;

	XtGetToken();
	return_val = XtDisplayToApplicationContext(dpy);
	XtReleaseToken();
	return return_val;
}


void
XtErrorR(message)
	CONST String    message;
{
	XtGetToken();
	XtError(message);
	XtReleaseToken();
}


void
XtErrorMsgR(name, type, class, defaultp, params, num_params)
	CONST String    name;
	CONST String    type;
	CONST String    class;
	CONST String    defaultp;
	String         *params;
	Cardinal       *num_params;
{
	XtGetToken();
	XtErrorMsg(name, type, class, defaultp, params, num_params);
	XtReleaseToken();
}


String
XtFindFileR(path, substitutions, num_substitutions, predicate)
	CONST String    path;
	Substitution    substitutions;
	Cardinal        num_substitutions;
	XtFilePredicate predicate;
{
	String return_val;

	XtGetToken();
	return_val = XtFindFile(path, substitutions, num_substitutions, predicate);
	XtReleaseToken();
	return return_val;
}


void
XtFreeR(ptr)
	char           *ptr;
{
	XtGetToken();
	XtFree(ptr);
	XtReleaseToken();
}


KeySym
XtGetActionKeysymR(event, modifiers_return)
	XEvent         *event;
	Modifiers      *modifiers_return;
{
	KeySym return_val;

	XtGetToken();
	return_val = XtGetActionKeysym(event, modifiers_return);
	XtReleaseToken();
	return return_val;
}


void
XtGetApplicationNameAndClassR(dpy, name_return, class_return)
	Display        *dpy;
	String         *name_return;
	String         *class_return;
{
	XtGetToken();
	XtGetApplicationNameAndClass(dpy, name_return, class_return);
	XtReleaseToken();
}


void
XtGetApplicationResourcesR(widget, base, resources, num_resources, args, num_args)
	Widget          widget;
	XtPointer       base;
	XtResourceList  resources;
	Cardinal        num_resources;
	ArgList         args;
	Cardinal        num_args;
{
	XtGetToken();
	XtGetApplicationResources(widget, base, resources, num_resources, args, num_args);
	XtReleaseToken();
}


void
XtGetConstraintResourceListR(widget_class, resources_return, num_resources_return)
	WidgetClass     widget_class;
	XtResourceList *resources_return;
	Cardinal       *num_resources_return;
{
	XtGetToken();
	XtGetConstraintResourceList(widget_class, resources_return, num_resources_return);
	XtReleaseToken();
}


XrmDatabase    *
XtGetErrorDatabaseR()
{
	XrmDatabase *return_val;

	XtGetToken();
	return_val = XtGetErrorDatabase();
	XtReleaseToken();
	return return_val;
}


void
XtGetErrorDatabaseTextR(name, type, class, defaultp, buffer, nbytes)
	CONST String    name;
	CONST String    type;
	CONST String    class;
	CONST String    defaultp;
	String          buffer;
	int             nbytes;
{
	XtGetToken();
	XtGetErrorDatabaseText(name, type, class, defaultp, buffer, nbytes);
	XtReleaseToken();
}


GC
XtGetGCR(widget, valueMask, values)
	Widget          widget;
	XtGCMask        valueMask;
	XGCValues      *values;
{
	GC return_val;

	XtGetToken();
	return_val = XtGetGC(widget, valueMask, values);
	XtReleaseToken();
	return return_val;
}


KeySym         *
XtGetKeysymTableR(dpy, min_keycode_return, keysyms_per_keycode_return)
	Display        *dpy;
	KeyCode        *min_keycode_return;
	int            *keysyms_per_keycode_return;
{
	KeySym *return_val;

	XtGetToken();
	return_val = XtGetKeysymTable(dpy, min_keycode_return, keysyms_per_keycode_return);
	XtReleaseToken();
	return return_val;
}


int
XtGetMultiClickTimeR(dpy)
	Display        *dpy;
{
	int return_val;

	XtGetToken();
	return_val = XtGetMultiClickTime(dpy);
	XtReleaseToken();
	return return_val;
}


void
XtGetResourceListR(widget_class, resources_return, num_resources_return)
	WidgetClass     widget_class;
	XtResourceList *resources_return;
	Cardinal       *num_resources_return;
{
	XtGetToken();
	XtGetResourceList(widget_class, resources_return, num_resources_return);
	XtReleaseToken();
}


XSelectionRequestEvent *
XtGetSelectionRequestR(widget, selection, request_id)
	Widget          widget;
	Atom            selection;
	XtRequestId     request_id;
{
	XSelectionRequestEvent *return_val;

	XtGetToken();
	return_val = XtGetSelectionRequest(widget, selection, request_id);
	XtReleaseToken();
	return return_val;
}


unsigned int
XtGetSelectionTimeoutR()
{
	unsigned int return_val;

	XtGetToken();
	return_val = XtGetSelectionTimeout();
	XtReleaseToken();
	return return_val;
}


void
XtGetSelectionValueR(widget, selection, target, callback, closure, time)
	Widget          widget;
	Atom            selection;
	Atom            target;
	XtSelectionCallbackProc callback;
	XtPointer       closure;
	Time            time;
{
	XtGetToken();
	XtGetSelectionValue(widget, selection, target, callback, closure, time);
	XtReleaseToken();
}


void
XtGetSelectionValueIncrementalR(widget, selection, target, selection_callback, client_data, time)
	Widget          widget;
	Atom            selection;
	Atom            target;
	XtSelectionCallbackProc selection_callback;
	XtPointer       client_data;
	Time            time;
{
	XtGetToken();
	XtGetSelectionValueIncremental(widget, selection, target, selection_callback, client_data, time);
	XtReleaseToken();
}


void
XtGetSelectionValuesR(widget, selection, targets, count, callback, closures, time)
	Widget          widget;
	Atom            selection;
	Atom           *targets;
	int             count;
	XtSelectionCallbackProc callback;
	XtPointer      *closures;
	Time            time;
{
	XtGetToken();
	XtGetSelectionValues(widget, selection, targets, count, callback, closures, time);
	XtReleaseToken();
}


void
XtGetSelectionValuesIncrementalR(widget, selection, targets, count, callback, client_data, time)
	Widget          widget;
	Atom            selection;
	Atom           *targets;
	int             count;
	XtSelectionCallbackProc callback;
	XtPointer      *client_data;
	Time            time;
{
	XtGetToken();
	XtGetSelectionValuesIncremental(widget, selection, targets, count, callback, client_data, time);
	XtReleaseToken();
}


void
XtGetSubresourcesR(widget, base, name, class, resources, num_resources, args, num_args)
	Widget          widget;
	XtPointer       base;
	CONST String    name;
	CONST String    class;
	XtResourceList  resources;
	Cardinal        num_resources;
	ArgList         args;
	Cardinal        num_args;
{
	XtGetToken();
	XtGetSubresources(widget, base, name, class, resources, num_resources, args, num_args);
	XtReleaseToken();
}


void
XtGetSubvaluesR(base, resources, num_resources, args, num_args)
	XtPointer       base;
	XtResourceList  resources;
	Cardinal        num_resources;
	ArgList         args;
	Cardinal        num_args;
{
	XtGetToken();
	XtGetSubvalues(base, resources, num_resources, args, num_args);
	XtReleaseToken();
}


void
XtGetValuesR(widget, args, num_args)
	Widget          widget;
	ArgList         args;
	Cardinal        num_args;
{
	XtGetToken();
	XtGetValues(widget, args, num_args);
	XtReleaseToken();
}


void
XtGrabButtonR(widget, button, modifiers, owner_events, event_mask, pointer_mode, keyboard_mode, confine_to, cursor)
	Widget          widget;
	int             button;
	Modifiers       modifiers;
	Boolean         owner_events;
	unsigned int    event_mask;
	int             pointer_mode;
	int             keyboard_mode;
	Window          confine_to;
	Cursor          cursor;
{
	XtGetToken();
	XtGrabButton(widget, button, modifiers, owner_events, event_mask, pointer_mode, keyboard_mode, confine_to, cursor);
	XtReleaseToken();
}


void
XtGrabKeyR(widget, keycode, modifiers, owner_events, pointer_mode, keyboard_mode)
	Widget          widget;
	KeyCode         keycode;
	Modifiers       modifiers;
	Boolean         owner_events;
	int             pointer_mode;
	int             keyboard_mode;
{
	XtGetToken();
	XtGrabKey(widget, keycode, modifiers, owner_events, pointer_mode, keyboard_mode);
	XtReleaseToken();
}


int
XtGrabKeyboardR(widget, owner_events, pointer_mode, keyboard_mode, time)
	Widget          widget;
	Boolean         owner_events;
	int             pointer_mode;
	int             keyboard_mode;
	Time            time;
{
	int return_val;
	XtGetToken();
	return_val = XtGrabKeyboard(widget, owner_events, pointer_mode, keyboard_mode, time);
	XtReleaseToken();
	return return_val;
}


int
XtGrabPointerR(widget, owner_events, event_mask, pointer_mode, keyboard_mode, confine_to, cursor, time)
	Widget          widget;
	Boolean         owner_events;
	unsigned int    event_mask;
	int             pointer_mode;
	int             keyboard_mode;
	Window          confine_to;
	Cursor          cursor;
	Time            time;
{
	int return_val;

	XtGetToken();
	return_val = XtGrabPointer(widget, owner_events, event_mask, pointer_mode, keyboard_mode, confine_to, cursor, time);
	XtReleaseToken();
	return return_val;
}


XtCallbackStatus
XtHasCallbacksR(widget, callback_name)
	Widget          widget;
	CONST String    callback_name;
{
	XtCallbackStatus return_val;

	XtGetToken();
	return_val = XtHasCallbacks(widget, callback_name);
	XtReleaseToken();
	return return_val;
}


Widget
XtInitializeR(name, class, options, num_options, argc, argv)
	CONST String    name;
	CONST String    class;
	XrmOptionDescRec *options;
	Cardinal        num_options;
	Cardinal       *argc;
	char          **argv;
{
	Widget return_val;

	XtInitializeToken(); 
	return_val = XtInitialize(name, class, options, num_options, argc, argv);
	XtInitializeTokenDispatch(); 
	return return_val;
}


void
XtInitializeWidgetClassR(widget_class)
	WidgetClass     widget_class;
{
	XtGetToken();
	XtInitializeWidgetClass(widget_class);
	XtReleaseToken();
}


void
XtInsertEventHandlerR(widget, eventMask, nonmaskable, proc, closure, position)
	Widget          widget;
	EventMask       eventMask;
	Boolean         nonmaskable;
	XtEventHandler  proc;
	XtPointer       closure;
	XtListPosition  position;
{
	XtGetToken();
	XtInsertEventHandler(widget, eventMask, nonmaskable, proc, closure, position);
	XtReleaseToken();
}


void
XtInsertRawEventHandlerR(widget, eventMask, nonmaskable, proc, closure, position)
	Widget          widget;
	EventMask       eventMask;
	Boolean         nonmaskable;
	XtEventHandler  proc;
	XtPointer       closure;
	XtListPosition  position;
{
	XtGetToken();
	XtInsertRawEventHandler(widget, eventMask, nonmaskable, proc, closure, position);
	XtReleaseToken();
}


void
XtInstallAcceleratorsR(destination, source)
	Widget          destination;
	Widget          source;
{
	XtGetToken();
	XtInstallAccelerators(destination, source);
	XtReleaseToken();
}


void
XtInstallAllAcceleratorsR(destination, source)
	Widget          destination;
	Widget          source;
{
	XtGetToken();
	XtInstallAllAccelerators(destination, source);
	XtReleaseToken();
}


Boolean
XtIsManagedR(rectobj)
	Widget          rectobj;
{
	Boolean return_val;

	XtGetToken();
	return_val = XtIsManaged(rectobj);
	XtReleaseToken();
	return return_val;
}


Boolean
XtIsObjectR(object)
	Widget          object;
{
	Boolean return_val;

	XtGetToken();
	return_val = XtIsObject(object);
	XtReleaseToken();
	return return_val;
}


Boolean
XtIsRealizedR(widget)
	Widget          widget;
{
	Boolean return_val;

	XtGetToken();
	return_val = XtIsRealized(widget);
	XtReleaseToken();
	return return_val;
}


Boolean
XtIsSensitiveR(widget)
	Widget          widget;
{
	Boolean return_val;

	XtGetToken();
	return_val = XtIsSensitive(widget);
	XtReleaseToken();
	return return_val;
}


Boolean
XtIsSubclassR(widget, widgetClass)
	Widget          widget;
	WidgetClass     widgetClass;
{
	Boolean return_val;

	XtGetToken();
	return_val = XtIsSubclass(widget, widgetClass);
	XtReleaseToken();
	return return_val;
}


void
XtKeysymToKeycodeListR(dpy, keysym, keycodes_return, keycount_return)
	Display        *dpy;
	KeySym          keysym;
	KeyCode       **keycodes_return;
	Cardinal       *keycount_return;
{
	XtGetToken();
	XtKeysymToKeycodeList(dpy, keysym, keycodes_return, keycount_return);
	XtReleaseToken();
}


Time
XtLastTimestampProcessedR(dpy)
	Display        *dpy;
{
	Time return_val;

	XtGetToken();
	return_val = XtLastTimestampProcessed(dpy);
	XtReleaseToken();
	return return_val;
}


void
XtMainLoopR()
{
	XtGetToken();
	XtMainLoop();
	XtReleaseToken();
}


XtGeometryResult
XtMakeGeometryRequestR(widget, request, reply_return)
	Widget          widget;
	XtWidgetGeometry *request;
	XtWidgetGeometry *reply_return;
{ 
	XtGeometryResult return_val;

	XtGetToken();
	return_val = XtMakeGeometryRequest(widget, request, reply_return);
	XtReleaseToken();
	return return_val;
}


XtGeometryResult
XtMakeResizeRequestR(widget, width, height, replyWidth, replyHeight)
	Widget          widget;
	Dimension       width;
	Dimension       height;
	Dimension      *replyWidth;
	Dimension      *replyHeight;
{
	XtGeometryResult return_val;

	XtGetToken();
	return_val = XtMakeResizeRequest(widget, width, height, replyWidth, replyHeight);
	XtReleaseToken();
	return return_val;
}


char           *
XtMallocR(size)
	Cardinal        size;
{
	char *return_val;

	XtGetToken();
	return_val = XtMalloc(size);
	XtReleaseToken();
	return return_val;
}


void
XtMenuPopupActionR(widget, event, params, num_params)
	Widget          widget;
	XEvent         *event;
	String         *params;
	Cardinal       *num_params;
{
	XtGetToken();
	XtMenuPopupAction(widget, event, params, num_params);
	XtReleaseToken();
}


ArgList
XtMergeArgListsR(args1, num_args1, args2, num_args2)
	ArgList         args1;
	Cardinal        num_args1;
	ArgList         args2;
	Cardinal        num_args2;
{
	ArgList return_val;

	XtGetToken();
	return_val = XtMergeArgLists(args1, num_args1, args2, num_args2);
	XtReleaseToken();
	return return_val;
}


String
XtNameR(object)
	Widget          object;
{
	String return_val;

	XtGetToken();
	return_val = XtName(object);
	XtReleaseToken();
	return return_val;
}


Widget
XtNameToWidgetR(root, name)
	Widget          root;
	CONST String    name;
{
	Widget return_val;

	XtGetToken();
	return_val = XtNameToWidget(root, name);
	XtReleaseToken();
	return return_val;
}


void
XtNextEventR(event)
	XEvent         *event;
{
	XtGetToken();
	XtNextEvent(event);
	XtReleaseToken();
}


Display        *
XtOpenDisplayR(appContext, displayName, applName, className, urlist, num_urs, argc, argv)
	XtAppContext    appContext;
	CONST String    displayName;
	CONST String    applName;
	CONST String    className;
	XrmOptionDescRec *urlist;
	Cardinal        num_urs;
	Cardinal       *argc;
	char          **argv;
{
	Display *return_val;
	XtGetToken();
	return_val = XtOpenDisplay(appContext, displayName, applName, className, urlist, num_urs, argc, argv);
	XtReleaseToken();
	return return_val;
}


void
XtOverrideTranslationsR(widget, new)
	Widget          widget;
	XtTranslations  new;
{
	XtGetToken();
	XtOverrideTranslations(widget, new);
	XtReleaseToken();
}


Boolean
XtOwnSelectionR(widget, selection, time, convert, lose, done)
	Widget          widget;
	Atom            selection;
	Time            time;
	XtConvertSelectionProc convert;
	XtLoseSelectionProc lose;
	XtSelectionDoneProc done;
{
	Boolean return_val;

	XtGetToken();
	return_val = XtOwnSelection(widget, selection, time, convert, lose, done);
	XtReleaseToken();
	return return_val;
}


Boolean
XtOwnSelectionIncrementalR(widget, selection, time, convert_callback, lose_callback, done_callback, cancel_callback, client_data)
	Widget          widget;
	Atom            selection;
	Time            time;
	XtConvertSelectionIncrProc convert_callback;
	XtLoseSelectionIncrProc lose_callback;
	XtSelectionDoneIncrProc done_callback;
	XtCancelConvertSelectionProc cancel_callback;
	XtPointer       client_data;
{
	Boolean return_val;

	XtGetToken();
	return_val = XtOwnSelectionIncremental(widget, selection, time, convert_callback, lose_callback, done_callback, cancel_callback, client_data);
	XtReleaseToken();
	return return_val;
}


Widget
XtParentR(widget)
	Widget          widget;
{
	Widget return_val;

	XtGetToken();
	return_val = XtParent(widget);
	XtReleaseToken();
	return return_val;
}


XtAccelerators
XtParseAcceleratorTableR(source)
	CONST String    source;
{
	XtAccelerators return_val;

	XtGetToken();
	return_val = XtParseAcceleratorTable(source);
	XtReleaseToken();
	return return_val;
}


XtTranslations
XtParseTranslationTableR(source)
	CONST String    source;
{
	XtTranslations return_val;

	XtGetToken();
	return_val = XtParseTranslationTable(source);
	XtReleaseToken();
	return return_val;
}


Boolean
XtPeekEventR(event)
	XEvent         *event;
{
	Boolean return_val;

	XtGetToken();
	return_val = XtPeekEvent(event);
	XtReleaseToken();
	return return_val;
}


XtInputMask
XtPendingR()
{
	XtInputMask return_val;

	XtGetToken();
	return_val = XtPending();
	XtReleaseToken();
	return return_val;
}


void
XtPopdownR(widget)
	Widget          widget;
{
	XtGetToken();
	XtPopdown(widget);
	XtReleaseToken();
}


void
XtPopupR(widget, grab_kind)
	Widget          widget;
	XtGrabKind      grab_kind;
{
	XtGetToken();
	XtPopup(widget, grab_kind);
	XtReleaseToken();
}


void
XtPopupSpringLoadedR(widget)
	Widget          widget;
{
	XtGetToken();
	XtPopupSpringLoaded(widget);
	XtReleaseToken();
}


void
XtProcessEventR(mask)
	XtInputMask     mask;
{
	XtGetToken();
	XtProcessEvent(mask);
	XtReleaseToken();
}


XtGeometryResult
XtQueryGeometryR(widget, intended, reply_return)
	Widget          widget;
	XtWidgetGeometry *intended;
	XtWidgetGeometry *reply_return;
{
	XtGeometryResult return_val;

	XtGetToken();
	return_val = XtQueryGeometry(widget, intended, reply_return);
	XtReleaseToken();
	return return_val;
}


void
XtRealizeWidgetR(widget)
	Widget          widget;
{
	XtGetToken();
	XtRealizeWidget(widget);
	XtReleaseToken();
}


char           *
XtReallocR(ptr, num)
	char           *ptr;
	Cardinal        num;
{
	char *return_val;

	XtGetToken();
	return_val = XtRealloc(ptr, num);
	XtReleaseToken();
	return return_val;
}


void
XtRegisterCaseConverterR(dpy, proc, start, stop)
	Display        *dpy;
	XtCaseProc      proc;
	KeySym          start;
	KeySym          stop;
{
	XtGetToken();
	XtRegisterCaseConverter(dpy, proc, start, stop);
	XtReleaseToken();
}


void
XtRegisterGrabActionR(action_proc, owner_events, event_mask, pointer_mode, keyboard_mode)
	XtActionProc    action_proc;
	Boolean         owner_events;
	unsigned int    event_mask;
	int             pointer_mode;
	int             keyboard_mode;
{
	XtGetToken();
	XtRegisterGrabAction(action_proc, owner_events, event_mask, pointer_mode, keyboard_mode);
	XtReleaseToken();
}


/*
 * This function is not defined in libXt.a, but is in Intrinsic.h.
 * It does not appear to be in the spec.  XtAppReleaseCacheRef is,
 * but there is no prototype in Intrinsic.h.
 *
 * void
 * XtReleaseCacheRefR(cache_ref)
 * 	XtCacheRef     *cache_ref;
 * {
 * 	XtGetToken();
 * 	XtReleaseCacheRef(cache_ref);
 * 	XtReleaseToken();
 * }
 */


void
XtReleaseGCR(object, gc)
	Widget          object;
	GC              gc;
{
	XtGetToken();
	XtReleaseGC(object, gc);
	XtReleaseToken();
}


void
XtRemoveActionHookR(id)
	XtActionHookId  id;
{
	XtGetToken();
	XtRemoveActionHook(id);
	XtReleaseToken();
}


void
XtRemoveAllCallbacksR(widget, callback_name)
	Widget          widget;
	CONST String    callback_name;
{
	XtGetToken();
	XtRemoveAllCallbacks(widget, callback_name);
	XtReleaseToken();
}


void
XtRemoveCallbackR(widget, callback_name, callback, closure)
	Widget          widget;
	CONST String    callback_name;
	XtCallbackProc  callback;
	XtPointer       closure;
{
	XtGetToken();
	XtRemoveCallback(widget, callback_name, callback, closure);
	XtReleaseToken();
}


void
XtRemoveCallbacksR(widget, callback_name, callbacks)
	Widget          widget;
	CONST String    callback_name;
	XtCallbackList  callbacks;
{
	XtGetToken();
	XtRemoveCallbacks(widget, callback_name, callbacks);
	XtReleaseToken();
}


void
XtRemoveEventHandlerR(widget, eventMask, nonmaskable, proc, closure)
	Widget          widget;
	EventMask       eventMask;
	Boolean         nonmaskable;
	XtEventHandler  proc;
	XtPointer       closure;
{
	XtGetToken();
	XtRemoveEventHandler(widget, eventMask, nonmaskable, proc, closure);
	XtReleaseToken();
}


void
XtRemoveGrabR(widget)
	Widget          widget;
{
	XtGetToken();
	XtRemoveGrab(widget);
	XtReleaseToken();
}


void
XtRemoveInputR(id)
	XtInputId       id;
{
	XtGetToken();
	XtRemoveInput(id);
	XtReleaseToken();
}


void
XtRemoveRawEventHandlerR(widget, eventMask, nonmaskable, proc, closure)
	Widget          widget;
	EventMask       eventMask;
	Boolean         nonmaskable;
	XtEventHandler  proc;
	XtPointer       closure;
{
	XtGetToken();
	XtRemoveRawEventHandler(widget, eventMask, nonmaskable, proc, closure);
	XtReleaseToken();
}


void
XtRemoveTimeOutR(timer)
	XtIntervalId    timer;
{
	XtGetToken();
	XtRemoveTimeOut(timer);
	XtReleaseToken();
}


void
XtRemoveWorkProcR(id)
	XtWorkProcId    id;
{
	XtGetToken();
	XtRemoveWorkProc(id);
	XtReleaseToken();
}


String
XtResolvePathnameR(dpy, type, filename, suffix, path, substitutions, num_substitutions, predicate)
	Display        *dpy;
	CONST String    type;
	CONST String    filename;
	CONST String    suffix;
	CONST String    path;
	Substitution    substitutions;
	Cardinal        num_substitutions;
	XtFilePredicate predicate;
{
	String return_val;
	XtGetToken();
	return_val = XtResolvePathname(dpy, type, filename, suffix, path, substitutions, num_substitutions, predicate);
	XtReleaseToken();
	return return_val;
}


Screen         *
XtScreenR(widget)
	Widget          widget;
{
	Screen *return_val;

	XtGetToken();
	return_val = XtScreen(widget);
	XtReleaseToken();
	return return_val;
}


Screen         *
XtScreenOfObjectR(object)
	Widget          object;
{
	Screen *return_val;

	XtGetToken();
	return_val = XtScreenOfObject(object);
	XtReleaseToken();
	return return_val;
}


void
XtSetErrorHandlerR(handler)
	XtErrorHandler  handler;
{
	XtGetToken();
	XtSetErrorHandler(handler);
	XtReleaseToken();
}


void
XtSetErrorMsgHandlerR(handler)
	XtErrorMsgHandler handler;
{
	XtGetToken();
	XtSetErrorMsgHandler(handler);
	XtReleaseToken();
}


void
XtSetKeyTranslatorR(dpy, proc)
	Display        *dpy;
	XtKeyProc       proc;
{
	XtGetToken();
	XtSetKeyTranslator(dpy, proc);
	XtReleaseToken();
}


void
XtSetKeyboardFocusR(subtree, descendent)
	Widget          subtree;
	Widget          descendent;
{
	XtGetToken();
	XtSetKeyboardFocus(subtree, descendent);
	XtReleaseToken();
}


void
XtSetMappedWhenManagedR(widget, mappedWhenManaged)
	Widget          widget;
	Boolean         mappedWhenManaged;
{
	XtGetToken();
	XtSetMappedWhenManaged(widget, mappedWhenManaged);
	XtReleaseToken();
}


void
XtSetMultiClickTimeR(dpy, milliseconds)
	Display        *dpy;
	int             milliseconds;
{
	XtGetToken();
	XtSetMultiClickTime(dpy, milliseconds);
	XtReleaseToken();
}


void
XtSetSelectionTimeoutR(timeout)
	unsigned long   timeout;
{
	XtGetToken();
	XtSetSelectionTimeout(timeout);
	XtReleaseToken();
}


void
XtSetSensitiveR(widget, sensitive)
	Widget          widget;
	Boolean         sensitive;
{
	XtGetToken();
	XtSetSensitive(widget, sensitive);
	XtReleaseToken();
}


void
XtSetSubvaluesR(base, resources, num_resources, args, num_args)
	XtPointer       base;
	XtResourceList  resources;
	Cardinal        num_resources;
	ArgList         args;
	Cardinal        num_args;
{
	XtGetToken();
	XtSetSubvalues(base, resources, num_resources, args, num_args);
	XtReleaseToken();
}


void
XtSetTypeConverterR(from_type, to_type, converter, convert_args, num_args, cache_type, destructor)
	CONST String    from_type;
	CONST String    to_type;
	XtTypeConverter converter;
	XtConvertArgList convert_args;
	Cardinal        num_args;
	XtCacheType     cache_type;
	XtDestructor    destructor;
{
	XtGetToken();
	XtSetTypeConverter(from_type, to_type, converter, convert_args, num_args, cache_type, destructor);
	XtReleaseToken();
}


void
XtSetValuesR(widget, args, num_args)
	Widget          widget;
	ArgList         args;
	Cardinal        num_args;
{
	XtGetToken();
	XtSetValues(widget, args, num_args);
	XtReleaseToken();
}


void
XtSetWMColormapWindowsR(widget, list, count)
	Widget          widget;
	Widget         *list;
	Cardinal        count;
{
	XtGetToken();
	XtSetWMColormapWindows(widget, list, count);
	XtReleaseToken();
}


void
XtSetWarningHandlerR(handler)
	XtErrorHandler  handler;
{
	XtGetToken();
	XtSetWarningHandler(handler);
	XtReleaseToken();
}


void
XtSetWarningMsgHandlerR(handler)
	XtErrorMsgHandler handler;
{
	XtGetToken();
	XtSetWarningMsgHandler(handler);
	XtReleaseToken();
}


void
XtStringConversionWarningR(from, toType)
CONST String    from;
CONST String    toType;
{
	XtGetToken();
	XtStringConversionWarning(from, toType);
	XtReleaseToken();
}


WidgetClass
XtSuperclassR(object)
	Widget          object;
{
	WidgetClass return_val;

	XtGetToken();
	return_val = XtSuperclass(object);
	XtReleaseToken();
	return return_val;
}


void
XtToolkitInitializeR()
{
	XtInitializeToken();
	XtToolkitInitialize();
	XtInitializeTokenDispatch();
}


void
XtTranslateCoordsR(widget, x, y, rootx_return, rooty_return)
	Widget          widget;
	Position        x;
	Position        y;
	Position       *rootx_return;
	Position       *rooty_return;
{
	XtGetToken();
	XtTranslateCoords(widget, x, y, rootx_return, rooty_return);
	XtReleaseToken();
}


void
XtTranslateKeyR(dpy, keycode, modifiers, modifiers_return, keysym_return)
	Display        *dpy;
	KeyCode         keycode;
	Modifiers       modifiers;
	Modifiers      *modifiers_return;
	KeySym         *keysym_return;
{
	XtGetToken();
	XtTranslateKey(dpy, keycode, modifiers, modifiers_return, keysym_return);
	XtReleaseToken();
}


void
XtTranslateKeycodeR(dpy, keycode, modifiers, modifiers_return, keysym_return)
	Display        *dpy;
	KeyCode         keycode;
	Modifiers       modifiers;
	Modifiers      *modifiers_return;
	KeySym         *keysym_return;
{
	XtGetToken();
	XtTranslateKeycode(dpy, keycode, modifiers, modifiers_return, keysym_return);
	XtReleaseToken();
}


void
XtUngrabButtonR(widget, button, modifiers)
	Widget          widget;
	unsigned int    button;
	Modifiers       modifiers;
{
	XtGetToken();
	XtUngrabButton(widget, button, modifiers);
	XtReleaseToken();
}


void
XtUngrabKeyR(widget, keycode, modifiers)
	Widget          widget;
	KeyCode         keycode;
	Modifiers       modifiers;
{
	XtGetToken();
	XtUngrabKey(widget, keycode, modifiers);
	XtReleaseToken();
}


void
XtUngrabKeyboardR(widget, time)
	Widget          widget;
	Time            time;
{
	XtGetToken();
	XtUngrabKeyboard(widget, time);
	XtReleaseToken();
}


void
XtUngrabPointerR(widget, time)
	Widget          widget;
	Time            time;
{
	XtGetToken();
	XtUngrabPointer(widget, time);
	XtReleaseToken();
}


void
XtUninstallTranslationsR(widget)
	Widget          widget;
{
	XtGetToken();
	XtUninstallTranslations(widget);
	XtReleaseToken();
}

#ifdef FIXME


{
	XtGetToken();
	XtUnmanageChild();
	XtReleaseToken();
}


{
	XtGetToken();
	XtUnmanageChildren();
	XtReleaseToken();
}
#endif


void
XtUnrealizeWidgetR(widget)
	Widget          widget;
{
	XtGetToken();
	XtUnrealizeWidget(widget);
	XtReleaseToken();
}


void
XtWarningR(message)
	CONST String    message;
{
	XtGetToken();
	XtWarning(message);
	XtReleaseToken();
}


void
XtWarningMsgR(name, type, class, defaultp, params, num_params)
	CONST String    name;
	CONST String    type;
	CONST String    class;
	CONST String    defaultp;
	String         *params;
	Cardinal       *num_params;
{
	XtGetToken();
	XtWarningMsg(name, type, class, defaultp, params, num_params);
	XtReleaseToken();
}


XtAppContext
XtWidgetToApplicationContextR(widget)
	Widget          widget;
{
	XtAppContext return_val;

	XtGetToken();
	return_val = XtWidgetToApplicationContext(widget);
	XtReleaseToken();
	return return_val;
}


Window
XtWindowR(widget)
	Widget          widget;
{
	Window return_val;

	XtGetToken();
	return_val = XtWindow(widget);
	XtReleaseToken();
	return return_val;
}


Window
XtWindowOfObjectR(object)
	Widget          object;
{
	Window return_val;

	XtGetToken();
	return_val = XtWindowOfObject(object);
	XtReleaseToken();
	return return_val;
}


Widget
XtWindowToWidgetR(display, window)
	Display        *display;
	Window          window;
{
	Widget return_val;

	XtGetToken();
	return_val = XtWindowToWidget(display, window);
	XtReleaseToken();
	return return_val;
}

#ifdef FIXME


) {
	XtGetToken();
	_XtCheckSubclassFlag();
	XtReleaseToken();
}


) {
	XtGetToken();
	_XtIsSubclassOf();
	XtReleaseToken();
}
#endif
